<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
version="1.0">
	<xsl:template match="/">
		<html>
			<head>
				<title>Metadaten zu "<xsl:value-of select="metadata/idinfo/citation/citeinfo/title"/>"</title>
				<style>
					body {
						font-family: Verdana, Arial, Helvetica;
						color="#191970";
						}
					h1 {
						margin-bottom: 0;
						text-align: center;
						font-size: 13pt;
						color="#006400";
						border: solid 0px silver;
						}
					h2 {
						margin-top: 5px;
						text-align: center;
						font-size: 10pt;
						color="#006400";
						border: solid 0px silver;
						}
					h3 {
						margin-top: 40px;
						padding: 3px;
						font-size: 11pt;
						font-weight: bold;
						border-bottom: solid 2px #6495ED;
						background-color:#B8E6FF;
						}
					h4 {
						margin-bottom: 0; 
						font-size: 10pt;
						border: solid 0px silver;
						}
					p {
						margin-top: 5px; 
						margin-left: 20px;
						font-size: 10pt;
						border: solid 0px silver;
						}

					<!-- Skript "fix ersetzt Text durch irgendeinen div. Formatierung
						 aller div ist nicht sehr elegant, aber trifft die richtigen
						 Abstze -->
					div {
						margin-top: 5px; 
						margin-left: 20px;
						font-size: 10pt;
						border: solid 0px silver;
						}
					table {
						margin-top: 5px;
						margin-left: 20px;
						}
					th, td {
						font-size: 10pt;
						}		

					<!-- Trennlinien in der Tabelle "Attribute" -->
					#attribute td {
						border-top: solid 1px silver;
						}
					<!-- Kopfzeile der Tabelle "Umgrenzendes Rechteck" -->
					#umgrenzendesRechteck th {
						font-weight: normal;
						text-align: left;
						border-bottom: solid 1px silver;
						{

				</style>
			</head>

      <SCRIPT LANGUAGE="JScript"><xsl:comment><![CDATA[
       //parse text to respect line breaks added - increases readability.
      //lines beginning with a ">" character are presented with a monospace
      //(fixed-width) font - e.g., so equations will appear correctly
      //created by Environmental Systems Research Institute, FGDC EXRI.xsl
      function fix(e) {
        var par = e.parentNode;
        e.id = "";
        var pos = e.innerText.indexOf("\n");
        if (pos > 0) {
          while (pos > 0) {
            var t = e.childNodes(0);
            var n = document.createElement("PRE");
            var s = t.splitText(pos);
            e.insertAdjacentElement("afterEnd", n);
            n.appendChild(s);
            e = n;
            pos = e.innerText.indexOf("\n");
          }
          var count = (par.children.length);
          for (var i = 0; i < count; i++) {
            e = par.children(i);
            if (e.tagName == "PRE") {
              pos = e.innerText.indexOf(">");
              if (pos != 0) {
                n = document.createElement("DIV");
                e.insertAdjacentElement("afterEnd", n);
                n.innerText = e.innerText;
                e.removeNode(true);
              }
            }
          }
          if (par.children.tags("PRE").length > 0) {
            count = (par.childNodes.length);
            for (i = 0; i < count; i++) {
              e = par.children(i);
              if (e.tagName == "PRE") {
                e.id = "";
                if (i < (count-1)) {
                  var e2 = par.children(i + 1);
                  if (e2.tagName == "PRE") {
                    e.insertAdjacentText("beforeEnd", e2.innerText+"\n");
                    e2.removeNode(true);
                    count = count-1;
                    i = i-1;
                  }
                }
              }
            }
          }
        }
        else {
          n = document.createElement("DIV");
          par.appendChild(n);
          n.innerText = e.innerText;
          e.removeNode(true);
        }
      }

      ]]></xsl:comment></SCRIPT>

			<body>
				<h1><xsl:value-of select="metadata/idinfo/citation/citeinfo/title"/></h1>
				<h2><xsl:value-of select="/metadata/idinfo/natvform"/> - 
				<xsl:value-of select="/metadata/spdoinfo/ptvctinf/esriterm/efeageom"/></h2>
				
				<h3>Beschreibung</h3>
				<h4>Dateiname</h4>
					<p><xsl:value-of select="/metadata/idinfo/citation/citeinfo/ftname"/> (<xsl:value-of select="/metadata/idinfo/natvform"/>)</p>
				<h4 title="Erstes Schlagwort entspricht Titel des Datensatzes">Schlagwrter</h4>
					<p><xsl:for-each select="metadata/idinfo/keywords/theme/themekey">
						<xsl:value-of select="."/><xsl:if test="not(position()=last())">, </xsl:if>
					</xsl:for-each></p>
				<h4>Zusammenfassung</h4>
					<SPAN CLASS="lt"><PRE ID="zusammenfassung"><xsl:value-of select="metadata/idinfo/descript/abstract"/></PRE></SPAN><BR/>
					<SCRIPT>fix(zusammenfassung)</SCRIPT>
				<h4>Erfassungsziel</h4>
					<SPAN CLASS="lt"><PRE ID="erfassungsziel"><xsl:value-of select="metadata/idinfo/descript/purpose"/></PRE></SPAN><BR/>
					<SCRIPT>fix(erfassungsziel)</SCRIPT>
				<h4 title="in Arbeit | abgeschlossen">Bearbeitungsstatus</h4>
					<p><xsl:value-of select="metadata/idinfo/status/progress"/></p>
				<h4>Bearbeitungsschritte</h4>
					<xsl:for-each select="metadata/dataqual/lineage/procstep/procdesc">
						<p style="margin-bottom:0"><xsl:value-of select="."/></p>
					</xsl:for-each>
				<h4>Zeitraum der Gltigkeit</h4>
					<p>
						<!--Einzelwert: wird nur angezeigt, wenn passender Knoten vorhanden ist-->
						<xsl:value-of select="metadata/idinfo/timeperd/timeinfo/sngdate/caldate"/>
						<!--Beginn und Ende: wird nur angezeigt, wenn passender Knoten vorhanden ist-->
						<xsl:value-of select="metadata/idinfo/timeperd/timeinfo/rngdates/begdate"/>
						 - 
						 <xsl:value-of select="metadata/idinfo/timeperd/timeinfo/rngdates/enddate"/>
					 </p>
				<h4 title="Vorname NACHNAME (Unternehmen Ort)">Autoren</h4>
					<p><xsl:for-each select="metadata/idinfo/citation/citeinfo/origin">
						<xsl:value-of select="."/><xsl:if test="not(position()=last())">, </xsl:if>
					</xsl:for-each></p>
				<h4>Datum der Verffentlichung</h4>
					<p><xsl:value-of select="metadata/idinfo/citation/citeinfo/pubdate"/></p>


				<h3>Raumbezug</h3>
				<h4>Koordinatensystem</h4>
				<table border="0" cellpadding="1" cellspacing="0" summary="">
					<tr>
						<td>Name:</td>
						<td><xsl:value-of select="metadata/spref/horizsys/cordsysn/projcsn"/></td>
					</tr>
					<tr>
						<td>Projektion:</td>
						<td><xsl:value-of select="metadata/spref/horizsys/planar/mapproj/mapprojn"/></td>
					</tr>
					<!--Die folgenden Tags sind wahrscheinlich typisch fr Transverse Mercator-->
					<tr>
						<td title="Geographische Lnge des Bezugsmeridians" style="padding-right: 10px;">Bezugsmeridian:</td>
						<td><xsl:value-of select="metadata/spref/horizsys/planar/mapproj/transmer/longcm"/></td>
					</tr>
					<tr>
						<td>False Easting:</td>
						<td><xsl:value-of select="metadata/spref/horizsys/planar/mapproj/transmer/feast"/></td>
					</tr>
					<tr>
						<td>False Northing:</td>
						<td><xsl:value-of select="metadata/spref/horizsys/planar/mapproj/transmer/fnorth"/></td>
					</tr>
				</table>

				<!--Umgrenzendes Rechteck-->
				<h4>Umgrenzung</h4>
				<table id="umgrenzendesRechteck" border="0px" cellpadding="1px" cellspacing="0" summary="">
					<colgroup>
						<col width="70px" style="border-right: solid 1px red;"/>
						<!--<col width="150px"/>
						<col width="150px"/>-->
					</colgroup>
					<tr>
						<th>Richtung</th>
						<th style="padding-right: 10px;">Dezimalgrad</th>
						<th>Lokale Koordinaten</th>
					</tr>
					<tr>
						<td>West</td>
						<td><xsl:value-of select="metadata/dataIdInfo/geoBox/westBL"/></td>
						<td><xsl:value-of select="metadata/dataIdInfo/dataExt/geoEle/GeoBndBox/westBL"/></td>
					</tr>
					<tr>
						<td>Ost</td>
						<td><xsl:value-of select="metadata/dataIdInfo/geoBox/eastBL"/></td>
						<td><xsl:value-of select="metadata/dataIdInfo/dataExt/geoEle/GeoBndBox/eastBL"/></td>
					</tr>
					<tr>
						<td>Nord</td>
						<td><xsl:value-of select="metadata/dataIdInfo/geoBox/northBL"/></td>
						<td><xsl:value-of select="metadata/dataIdInfo/dataExt/geoEle/GeoBndBox/northBL"/></td>
					</tr>
					<tr>
						<td>Sd</td>
						<td><xsl:value-of select="metadata/dataIdInfo/geoBox/southBL"/></td>
						<td><xsl:value-of select="metadata/dataIdInfo/dataExt/geoEle/GeoBndBox/southBL"/></td>
					</tr>
				</table>

				<h3>Attribute</h3>


				
				<table id="attribute" border="0" cellpadding="1" cellspacing="0" summary="">
				<tr style="border-bottom: solid 1px green;">
					<th>Attribut</th>
					<th>Typ(Lnge)</th>
					<th>Beschreibung</th>
				</tr>
				<xsl:for-each select="metadata/eainfo/detailed/attr">
				<xsl:sort select="attrlabl"/>
				<tr>
					<td><xsl:value-of select="attrlabl"/></td>
					<td><xsl:value-of select="attrtype"/>(<xsl:value-of select="attwidth"/>)</td>
					<td><xsl:value-of select="attrdef"/></td>
				</tr>
				</xsl:for-each>
				</table>
				

				
				<!--<xsl:for-each select="titelliste/heft">
					<xsl:sort select="titel"/>
					<h3><xsl:value-of select="titel"/></h3>
					<xsl:for-each select="autor">
						<i><xsl:value-of select="."/></i><br/>
					</xsl:for-each>
					<div><xsl:value-of select="verlag"/></div>
					<i><xsl:value-of select="beschreibung"/></i>
					<div><xsl:value-of select="preis"/></div>
				</xsl:for-each>-->
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>